@@ -14,6 +14,8 @@ from astropy import units as u
 import lmfit as lm
 from lmfit import Minimizer, Parameters, report_fit
 import PRF
+import sys
+
 
 
 class PixelMapFit:
@@ -87,7 +89,7 @@ class PixelMapFit:
         if self.pca_only == True:
             self.raw_lc1 = self.tpf.to_lightcurve(aperture_mask=self.aperture)
             self.quality_mask = [np.isfinite(self.raw_lc1['flux']*self.raw_lc1['flux_err'])]
-            if principal_components !=None:
+            if principal_components !=0:
                 self.dm = lk.DesignMatrix(self.tpf.flux[:,~self.tpf.pipeline_mask][np.isfinite(self.raw_lc1['flux']*self.raw_lc1['flux_err']),:][np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)[0],:], name='regressors').pca(principal_components)
                 self.raw_lc = self.raw_lc1[self.quality_mask[0]]
                 self.raw_lc = self.raw_lc[np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)]
@@ -105,10 +107,10 @@ class PixelMapFit:
                     ax[1].axvline(x = self.frequency_list[i],color='r',linestyle='--',linewidth=1)
                 g2 = self.raw_lc.plot(label='Raw light curve')
                 self.corrected_lc.plot(ax=g2, label='Corrected light curve')
-                quit()
+                sys.exit()
                 
             else:
-                quit()
+                sys.exit()
             
         if self.aperture is None:
             self.aperture = targetpixelfile.pipeline_mask
@@ -120,7 +122,7 @@ class PixelMapFit:
         # Make a design matrix and pass it to a linear regression corrector
         self.raw_lc1 = self.tpf.to_lightcurve(aperture_mask=self.aperture)
         self.quality_mask = [np.isfinite(self.raw_lc1['flux']*self.raw_lc1['flux_err'])]
-        if principal_components !=None:
+        if principal_components !=0:
             self.dm = lk.DesignMatrix(self.tpf.flux[:,~self.tpf.pipeline_mask][np.isfinite(self.raw_lc1['flux']*self.raw_lc1['flux_err']),:][np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)[0],:], name='regressors').pca(principal_components)
             self.raw_lc = self.raw_lc1[self.quality_mask[0]]
             self.raw_lc = self.raw_lc[np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)]
@@ -137,42 +139,78 @@ class PixelMapFit:
         
         
         def Obtain_Initial_Phase(tpf,corrected_lc,frequency_list):
-
             flux = corrected_lc.flux.value
             times = corrected_lc.time.value - np.nanmean(corrected_lc.time.value)
             #appending a extra value here to ensure lightkurve doesn't call an error if length of frequencies =1
             pg = corrected_lc.to_periodogram(frequency = np.append([0.0001],frequency_list),ls_method='slow')
-            initial_flux= np.asarray(pg.power[1:])
+            initial_amp= np.asarray(pg.power[1:])#initial_amp
 
             initial_phase = np.zeros(len(frequency_list))
+            mask = np.argsort(initial_amp)[::-1]
 
             def lc_model(time,amp,freq,phase):
                 return amp*np.sin(2*np.pi*freq*time + phase)
 
             def background_model(time,height):
                 return np.ones(len(time))*height
-            for j in np.arange(len(frequency_list)):
-                for i in np.arange(len(frequency_list)):
 
-                    if (i == 0):
-                        model = lm.Model(lc_model,independent_vars=['time'],prefix='f{0:d}'.format(i)) 
-                        model += lm.Model(background_model, independent_vars=['time'])
-                    else:
-                        model += lm.Model(lc_model,independent_vars=['time'],prefix='f{0:d}'.format(i))
-
-
-                    model.set_param_hint('f{0:d}phase'.format(i), min = -np.pi, max = np.pi ,value= initial_phase[i],vary = False)
-                    model.set_param_hint('f{0:d}amp'.format(i), value = initial_flux[i],vary=False)
+            model = lm.Model(background_model, independent_vars=['time'])
+            for j in mask:
+                model += lm.Model(lc_model,independent_vars=['time'],prefix='f{0:d}'.format(j))
+                for i in range(np.where(mask.value==j)[0][0]+1):
+                    model.set_param_hint('f{0:d}phase'.format(mask[i]), min = -np.pi, max = np.pi ,value= initial_phase[mask][i],vary = False)
+                    model.set_param_hint('f{0:d}amp'.format(mask[i]), value = initial_amp[mask][i],vary=False)
                     model.set_param_hint('height', value= np.nanmean(flux),vary=False)
-                    model.set_param_hint('f{0:d}freq'.format(i),value = frequency_list[i], vary = False)
+                    model.set_param_hint('f{0:d}freq'.format(mask[i]),value = frequency_list[mask][i], vary = False)
+
+            params = model.make_params()
+            #params['f{0:d}amp'.format(j)].set(value = initial_amp[j],vary=False)
+            params['f{0:d}phase'.format(j)].set(vary=True)
+            params['f{0:d}phase'.format(j)].set(value = initial_phase[j])
+            params['f{0:d}phase'.format(j)].set(brute_step=np.pi/10)
+            result = model.fit(corrected_lc.flux.value,params,time=times,method = 'brute')
+            initial_phase[j]=result.best_values['f{0:d}phase'.format(j)]    
+
+            return initial_phase
+
+self.initial_phases = Obtain_Initial_Phase(self.tpf,self.corrected_lc,self.frequency_list)
+
+#             flux = corrected_lc.flux.value
+#             times = corrected_lc.time.value - np.nanmean(corrected_lc.time.value)
+#             #appending a extra value here to ensure lightkurve doesn't call an error if length of frequencies =1
+#             pg = corrected_lc.to_periodogram(frequency = np.append([0.0001],frequency_list),ls_method='slow')
+#             initial_flux= np.asarray(pg.power[1:])#initial_amp
+
+#             initial_phase = np.zeros(len(frequency_list))
+
+#             def lc_model(time,amp,freq,phase):
+#                 return amp*np.sin(2*np.pi*freq*time + phase)
+
+#             def background_model(time,height):
+#                 return np.ones(len(time))*height
+#             for j in np.arange(len(frequency_list)):
+#                 for i in np.arange(len(frequency_list)):
+
+#                     if (i == 0):
+#                         model = lm.Model(lc_model,independent_vars=['time'],prefix='f{0:d}'.format(i)) 
+#                         model += lm.Model(background_model, independent_vars=['time'])
+#                     else:
+#                         model += lm.Model(lc_model,independent_vars=['time'],prefix='f{0:d}'.format(i))
 
 
-                params = model.make_params()
-                params['f{0:d}phase'.format(j)].set(vary=True)
-                params['f{0:d}phase'.format(j)].set(value = initial_phase[j])
-                params['f{0:d}phase'.format(j)].set(brute_step=np.pi/10)
-                result = model.fit(corrected_lc.flux.value,params,time=times,method = 'brute')
-                initial_phase[j]=result.best_values['f{0:d}phase'.format(j)]
+#                     model.set_param_hint('f{0:d}phase'.format(i), min = -np.pi, max = np.pi ,value= initial_phase[i],vary = False)
+#                     model.set_param_hint('f{0:d}amp'.format(i), value = initial_flux[i],vary=False)
+#                     model.set_param_hint('height', value= np.nanmean(flux),vary=False)
+#                     model.set_param_hint('f{0:d}freq'.format(i),value = frequency_list[i], vary = False)
+
+
+#                 params = model.make_params()
+#                 #params['f{0:d}amp'.format(j)].set(value = initial_flux[j],vary=False)
+#                 params['f{0:d}phase'.format(j)].set(vary=True)
+#                 params['f{0:d}phase'.format(j)].set(value = initial_phase[j])
+#                 params['f{0:d}phase'.format(j)].set(brute_step=np.pi/10)
+#                 result = model.fit(corrected_lc.flux.value,params,time=times,method = 'brute')
+#                 initial_phase[j]=result.best_values['f{0:d}phase'.format(j)]
 
             return initial_phase
         
@@ -275,7 +313,7 @@ class PixelMapFit:
                 lightcurve = lightcurve[np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)]
 
 
-                if principal_components !=None:
+                if principal_components !=0:
                     rcc = lk.RegressionCorrector(lightcurve)
                     lc = rcc.correct(self.dm.append_constant())
                 else:
@@ -376,7 +414,7 @@ class PixelMapFit:
                         y = params['y']
 
                         res = []
-                        localprf = self.prf.locate(x+.5, y+.5, (self.size[0],self.size[1]))
+                        localprf = self.prf.locate(x, y, (self.size[0],self.size[1]))
                         for i in np.arange(len(frequencies)):
                             height = params['height{0:d}'.format(i)]
                             model = height*localprf
@@ -492,7 +530,7 @@ class PixelMapFit:
             warnings.warn('Frequencies used may not all belong to the same source and provided fit could be unreliable')
     
     def pca(self):
-        if self.principal_components==None:
+        if self.principal_components==0:
             pass
         else:
             pgs = [lk.LightCurve(time = self.tpf.time.value[self.quality_mask[0]][np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)],flux =self.dm.values.T[i]).to_periodogram() for i in np.arange(0,len(self.dm.values.T))]
